@@ -40,15 +40,15 @@
 #include <tqfile.h>
 #include <tqfontmetrics.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
 
-#include <kdeversion.h>
-#include <kio/job.h>
-#include <kmessagebox.h>
+#include <tdeversion.h>
+#include <tdeio/job.h>
+#include <tdemessagebox.h>
 #include <kmimetype.h>
 #include <kprotocolinfo.h>
-#include <kfileitem.h>
+#include <tdefileitem.h>
 #include <kprocess.h>
 #include <tqcursor.h>
 
@@ -73,8 +73,8 @@
 MediaButton::MediaButton( TQWidget *parent, const char *name ) : TQToolButton( parent, name ),
 		popupMenu( 0 ), rightMenu( 0 ), hasMedia( false ), waitingForMount( -1 ), mountCheckerTimer()
 	 {
-	KIconLoader * iconLoader = new KIconLoader();
-	TQPixmap icon = iconLoader->loadIcon( "blockdevice", KIcon::Toolbar, 16 );
+	TDEIconLoader * iconLoader = new TDEIconLoader();
+	TQPixmap icon = iconLoader->loadIcon( "blockdevice", TDEIcon::Toolbar, 16 );
 
 	setFixedSize( icon.width() + 4, icon.height() + 4 );
 	setPixmap( icon );
@@ -84,7 +84,7 @@ MediaButton::MediaButton( TQWidget *parent, const char *name ) : TQToolButton( p
 
 	popupMenu = new TQPopupMenu( this );
 	popupMenu->installEventFilter( this );
-	Q_CHECK_PTR( popupMenu );
+	TQ_CHECK_PTR( popupMenu );
 
 	setPopup( popupMenu );
 
@@ -129,23 +129,23 @@ void MediaButton::slotAboutToHide() {
 }
 
 void MediaButton::createListWithMedia() {
-	KIO::ListJob *job = KIO::listDir( KURL( "media:/" ), false );
-	connect( job, TQT_SIGNAL( entries( KIO::Job*, const KIO::UDSEntryList& ) ),
-		this, TQT_SLOT( slotEntries( KIO::Job*, const KIO::UDSEntryList& ) ) );
-	connect( job, TQT_SIGNAL( result( KIO::Job* ) ),
-		this, TQT_SLOT( slotListResult( KIO::Job* ) ) );
+	TDEIO::ListJob *job = TDEIO::listDir( KURL( "media:/" ), false );
+	connect( job, TQT_SIGNAL( entries( TDEIO::Job*, const TDEIO::UDSEntryList& ) ),
+		this, TQT_SLOT( slotEntries( TDEIO::Job*, const TDEIO::UDSEntryList& ) ) );
+	connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ),
+		this, TQT_SLOT( slotListResult( TDEIO::Job* ) ) );
 	busy = true;
 	
 	if( !busy )
 		tqApp->processEvents();
 }
 
-void MediaButton::slotEntries( KIO::Job *, const KIO::UDSEntryList& entries ) 
+void MediaButton::slotEntries( TDEIO::Job *, const TDEIO::UDSEntryList& entries ) 
 {
 	KMountPoint::List mountList = KMountPoint::currentMountPoints();
 	
-	KIO::UDSEntryListConstIterator it = entries.begin();
-	KIO::UDSEntryListConstIterator end = entries.end();
+	TDEIO::UDSEntryListConstIterator it = entries.begin();
+	TDEIO::UDSEntryListConstIterator end = entries.end();
 	
 	while( it != end )
 	{
@@ -155,23 +155,23 @@ void MediaButton::slotEntries( KIO::Job *, const KIO::UDSEntryList& entries )
 		TQString localPath;
 		bool mounted = false;
 		
-		KIO::UDSEntry::ConstIterator it2 = (*it).begin();
+		TDEIO::UDSEntry::ConstIterator it2 = (*it).begin();
 		
 		for( ; it2 != (*it).end(); it2++ ) {
 			switch ((*it2).m_uds) {
-			case KIO::UDS_NAME:
+			case TDEIO::UDS_NAME:
 				text = KURL::decode_string((*it2).m_str);
 				break;
-			case KIO::UDS_URL:
+			case TDEIO::UDS_URL:
 				url = KURL::fromPathOrURL(  (*it2).m_str );
 				break;
-			case KIO::UDS_MIME_TYPE:
+			case TDEIO::UDS_MIME_TYPE:
 				mime = (*it2).m_str;
 				if( !mime.endsWith( "unmounted" ) )
 					mounted = true;
 				break;
 #if KDE_IS_VERSION(3,4,0)
-			case KIO::UDS_LOCAL_PATH:
+			case TDEIO::UDS_LOCAL_PATH:
 				localPath = (*it2).m_str;
 				break;
 #endif
@@ -207,7 +207,7 @@ void MediaButton::slotEntries( KIO::Job *, const KIO::UDSEntryList& entries )
 	}
 }
 
-void MediaButton::slotListResult( KIO::Job * ) {
+void MediaButton::slotListResult( TDEIO::Job * ) {
 	busy = false;
 }
 
@@ -373,9 +373,9 @@ void MediaButton::slotPopupActivated( int elem ) {
 void MediaButton::gettingSpaceData(const TQString &mountPoint, unsigned long kBSize, unsigned long, unsigned long ) {
 	KURL mediaURL = KURL::fromPathOrURL( mountPoint );
 	
-	KIO::filesize_t size = kBSize;
+	TDEIO::filesize_t size = kBSize;
 	size *= 1024;
-	TQString sizeText = KIO::convertSize( size );
+	TQString sizeText = TDEIO::convertSize( size );
 	
 	for( unsigned i=0; i != urls.size(); i++ ) {
 		if( mediaURL.equals( urls[ i ], true ) ) {
@@ -576,9 +576,9 @@ void MediaButton::rightClickMenu( int index ) {
 bool MediaButton::mount( int index ) {
 	if ( (unsigned)index < mimes.count() ) {
 		if( !mediaUrls[ index ].isEmpty() ) {
-			KProcess proc;
-			proc << KrServices::fullPathName( "kio_media_mounthelper" ) << "-m" << mediaUrls[ index ].url();
-			proc.start( KProcess::DontCare );
+			TDEProcess proc;
+			proc << KrServices::fullPathName( "tdeio_media_mounthelper" ) << "-m" << mediaUrls[ index ].url();
+			proc.start( TDEProcess::DontCare );
 		} else {
 			krMtMan.mount( urls[ index ].path(), false );
 		}
@@ -589,9 +589,9 @@ bool MediaButton::mount( int index ) {
 bool MediaButton::umount( int index ) {
 	if ( (unsigned)index < mimes.count() ) {
 		if( !mediaUrls[ index ].isEmpty() ) {
-			KProcess proc;
-			proc << KrServices::fullPathName( "kio_media_mounthelper" ) << "-u" << mediaUrls[ index ].url();
-			proc.start( KProcess::DontCare );
+			TDEProcess proc;
+			proc << KrServices::fullPathName( "tdeio_media_mounthelper" ) << "-u" << mediaUrls[ index ].url();
+			proc.start( TDEProcess::DontCare );
 		} else {
 			krMtMan.unmount( urls[ index ].path(), false );
 		}
@@ -602,9 +602,9 @@ bool MediaButton::umount( int index ) {
 bool MediaButton::eject( int index ) {
 	if ( (unsigned)index < mimes.count() ) {
 		if( !mediaUrls[ index ].isEmpty() ) {
-			KProcess proc;
-			proc << KrServices::fullPathName( "kio_media_mounthelper" ) << "-e" << mediaUrls[ index ].url();
-			proc.start( KProcess::DontCare );
+			TDEProcess proc;
+			proc << KrServices::fullPathName( "tdeio_media_mounthelper" ) << "-e" << mediaUrls[ index ].url();
+			proc.start( TDEProcess::DontCare );
 		} else {
 			krMtMan.eject( urls[ index ].path() );
 		}
